==> gbsite-1.1.1.tar.gz: gbsite/scripts/project/task/taskupdate.php <==
<?
    $web_page = "taskeditpage";
    include("site_info.php");
	$group_group_id = "tasks";

    $task_id = findTaskInProject($task_id,$project_id);
    $status_list = getTaskStatusList();

    if(empty($task_id)) {
        $web_page = "contextpage";
        $context = "Couldn't find the task specified in this project.";
    } else {
        $query = "select assigned_to from task where task_id = $task_id";
        $res   = pg_exec($conn,$query);
        $owner = pg_result($res,0,0);
        if($owner != $member_id && $access_level != 4) {
            $context = "You do not have access to update this task.";
            $web_page = "contextpage";
        } else {
            /* update the task here */
            $assigned_to = (empty($assigned_to)?"null":(int)$assigned_to);
            $start_date = sqlDate($start_date);
            $end_date   = sqlDate($end_date);
            $hours = (empty($hours)?"null":(int)$hours);
            $percent_done = (empty($percent_done)?"0":(int)$percent_done);
            $status_id = (empty($status_id)?"null":$status_id);
            $priority = (empty($priority)?"0":(int)$priority);
            $comments = sqlText($comments);
            $query = "update task ".
                     "   set assigned_to  = $assigned_to, ".
                     "       start_date   = $start_date, ".
                     "       end_date     = $end_date, ".
                     "       hours        = $hours, ".
                     "       percent_done = $percent_done, ".
                     "       status_id    = $status_id, ".
                     "       priority     = $priority, ".
                     "       comments     = $comments ".
                     " where task_id = $task_id ";
            $res   = pg_exec($conn,$query);

            $query = "select task_id,project_id,task_name,assigned_to, ". 
                 "       date(start_date) as start_date, ".
                 "       date(end_date) as end_date, ".
                 "       hours,percent_done,status_id,priority, ".
                 "       comments,created_by,date_created ".
                 "  from task ".
                 " where task_id = $task_id ";

            $res   = pg_exec($conn,$query);
            $task  = pg_fetch_array($res,0);
						
# change any bugs if necessary 
						$bug_query = "UPDATE BUG SET STATUS_ID = $status_id WHERE TASK_ID = $task_id";
						$bug_result = pg_exec($conn,$bug_query);

            /* do any processing here for the add form */
            $query = "  select member.member_id as member_id, ".
                     "         member.member_name as member_name ".
                     "    from member, member_role ".
                     "   where member.member_id = member_role.member_id ".
                     "     and member_role.project_id = $project_id ".
                     "order by member_name ";
            $res   = pg_exec($conn,$query);
            $r = 0;
            while($row = @pg_fetch_array($res,$r++)) {
                $project_members[$row["member_id"]] = $row["member_name"];
            }
				 RedirectTo("/project/$project_name/task/tasklist.php?success=yes");
			   exit;
        }
    }
    
    include($page_template);
 ?>

==> gbsite-2.0.0.tar.gz: gbsite/scripts/project/task/taskupdate.php <==
<?
    $web_page = "taskeditpage";
    include("site_info.php");
	$group_group_id = "tasks";

    $task_id = findTaskInProject($task_id,$project_id);
    $status_list = getTaskStatusList();

    if(empty($task_id)) {
        $web_page = "contextpage";
        $context = "Couldn't find the task specified in this project.";
    } else {
        $query = "select assigned_to from task where task_id = $task_id";
        $res   = pg_exec($conn,$query);
        $owner = pg_result($res,0,0);
        if($owner != $member_id && $access_level < 3) {
            $context = "You do not have access to update this task.";
            $web_page = "contextpage";
        } else {
            /* update the task here */
            $assigned_to = (empty($assigned_to)?"null":(int)$assigned_to);
            $start_date = sqlDate($start_date);
            $end_date   = sqlDate($end_date);
            $hours = (empty($hours)?"null":(int)$hours);
            $percent_done = (empty($percent_done)?"0":(int)$percent_done);
            $status_id = (empty($status_id)?"null":$status_id);
            $priority = (empty($priority)?"0":(int)$priority);
            $comments = sqlText($comments);
            $query = "update task ".
                     "   set assigned_to  = $assigned_to, ".
                     "       start_date   = $start_date, ".
                     "       end_date     = $end_date, ".
                     "       hours        = $hours, ".
                     "       percent_done = $percent_done, ".
                     "       status_id    = $status_id, ".
                     "       priority     = $priority, ".
                     "       comments     = $comments ".
                     " where task_id = $task_id ";
            $res   = pg_exec($conn,$query);

            if(!empty($owner) && $owner != $member_id) {
                mailTask($task_id, getMemberEmail($owner), "(UPDATE)",
                         "A change was made to this task by ".
                          getMemberName($member_id));
            }
            if($assigned_to != "null" && $assigned_to != $member_id) {
                mailTask($task_id, getMemberEmail($assigned_to), "(UPDATE)",
                         "This task has been assigned to you by ".
                          getMemberName($member_id));
            }

            $query = "select task_id,project_id,task_name,assigned_to, ". 
                 "       date(start_date) as start_date, ".
                 "       date(end_date) as end_date, ".
                 "       hours,percent_done,status_id,priority, ".
                 "       comments,created_by,date_created ".
                 "  from task ".
                 " where task_id = $task_id ";

            $res   = pg_exec($conn,$query);
            $task  = pg_fetch_array($res,0);

            # change any bugs if necessary 
            $bug_query = "UPDATE BUG SET STATUS_ID = $status_id ".
                         " WHERE TASK_ID = $task_id";
            $bug_result = pg_exec($conn,$bug_query);

            /* do any processing here for the add form */
            $query = "  select member.member_id as member_id, ".
                     "         member.member_name as member_name ".
                     "    from member, member_role ".
                     "   where member.member_id = member_role.member_id ".
                     "     and member_role.project_id = $project_id ".
                     "order by member_name ";
            $res   = pg_exec($conn,$query);
            $r = 0;
            while($row = @pg_fetch_array($res,$r++)) {
                $project_members[$row["member_id"]] = $row["member_name"];
            }
	    RedirectTo("/project/$project_name/task/tasklist.php?success=yes");
	    exit;
        }
    }
    
    include($page_template);
 ?>
